@@ -1,10 +1,13 @@
-﻿
 
 
-__version__ = "0.2022.2.11"
+
+__author__ = "Jürgen Knauth"
+__version__ = "0.2023.2.8"
 
 
 
 from .ArgOption import ArgOption
 from .ArgsParser import ArgsParser
-from .ParsedArgs import ParsedArgs
\ No newline at end of file
+from .ParsedArgs import ParsedArgs
+
+
